==> liveramp_automation-1.3.8.tar.gz: liveramp_automation-1.3.8/setup.py <==
from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

import os

version_ns = {}
with open(os.path.join("liveramp_automation", "__version__.py")) as f:
    exec(f.read(), version_ns)
version = version_ns['__version__']

setup(
    name='liveramp_automation',
    version=version,
    author='Jasmine Qian',
    author_email='jasmine.qian@liveramp.com',
    description="This is the base liveramp_automation_framework",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/LiveRamp/liveramp-automation",
    packages=find_packages(),
    install_requires=[
        'allure-pytest-bdd',
        'allure-python-commons',
        'boto3',
        'certifi',
        'datadog',
        'db-dtypes',
        'dnspython',
        'google',
        'google-api-core',
        'google-auth',
        'google-cloud-bigquery',
        'google-cloud-core',
        'google-cloud-storage',
        'google-crc32c',
        'google-resumable-media',
        'googleapis-common-protos',
        'httpx',
        'mysql-connector-python',
        'pandas',
        'pysftp',
        'pytest==7.4.4',
        'pytest-bdd==7.0.1',
        'pytest-json',
        'pytest-json-report',
        'pytest-playwright==0.4.3',
        'pytest-xdist==3.5.0',
        'python-dotenv',
        'PyYAML',
        'requests',
        'retrying',
        'snowflake-connector-python',
        'selenium==4.16.0',
    ],
)

==> liveramp_automation-1.4.3.tar.gz: liveramp_automation-1.4.3/setup.py <==
from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

import os

version_ns = {}
with open(os.path.join("liveramp_automation", "__version__.py")) as f:
    exec(f.read(), version_ns)
version = version_ns['__version__']

setup(
    name='liveramp_automation',
    version=version,
    author='Jasmine Qian',
    author_email='jasmine.qian@liveramp.com',
    description="This is the base liveramp_automation_framework",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/LiveRamp/liveramp-automation",
    packages=find_packages(),
    install_requires=[
        'allure-pytest-bdd',
        'allure-python-commons',
        'boto3',
        'certifi',
        'datadog',
        'db-dtypes',
        'dnspython',
        'google',
        'google-api-core',
        'google-auth',
        'google-cloud-bigquery',
        'google-cloud-core',
        'google-cloud-storage',
        'google-crc32c',
        'google-resumable-media',
        'googleapis-common-protos',
        'httpx',
        'mysql-connector-python',
        'pandas',
        'pysftp',
        'pytest==8.2.0',
        'pytest-bdd',
        'pytest-json',
        'pytest-json-report',
        'pytest-playwright',
        'pytest-xdist==3.6.1',
        'python-dotenv',
        'PyYAML',
        'requests',
        'retrying',
        'snowflake-connector-python',
        'selenium==4.16.0',
    ],
)
